@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.099-5-g5c5a470
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.100-10-g63bc7ce
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.100';
+our $VERSION = '0.101';
 
 use Moose;
 with
@@ -65,7 +65,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    _uniq($self->$orig(@_), qw(LICENSE CONTRIBUTING Changes ppport.h INSTALL));
+    _uniq($self->$orig(@_), qw(LICENCE LICENSE CONTRIBUTING Changes ppport.h INSTALL));
 };
 
 has changes_version_columns => (
@@ -74,6 +74,18 @@ has changes_version_columns => (
     default => sub { $_[0]->payload->{changes_version_columns} // 10 },
 );
 
+has licence => (
+    is => 'ro', isa => 'Str',
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        $self->payload->{licence}
+            // $self->payload->{license}
+            // (($self->payload->{'Authority.authority'} // 'cpan:ETHER') eq 'cpan:ETHER'
+                ? 'LICENCE' : 'LICENSE');
+    },
+);
+
 # configs are applied when plugins match ->isa($key) or ->does($key)
 my %extra_args = (
     'Dist::Zilla::Plugin::MakeMaker' => { 'eumm_version' => '0' },
@@ -104,7 +116,7 @@ my $has_bash = can_run('bash');
 # files that might be in the repository that should never be gathered
 my @never_gather = qw(
     Makefile.PL ppport.h README.md README.pod META.json
-    cpanfile TODO CONTRIBUTING LICENSE INSTALL
+    cpanfile TODO CONTRIBUTING LICENCE LICENSE INSTALL
     inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
 );
 
@@ -194,7 +206,8 @@ sub configure
             },
         } ],
 
-        qw(MetaYAML MetaJSON License Readme Manifest),
+        qw(MetaYAML MetaJSON Readme Manifest),
+        [ 'License'             => { ':version' => '5.038', filename => $self->licence } ],
         [ 'GenerateFile::ShareDir' => 'generate CONTRIBUTING' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING', has_xs => $has_xs } ],
         'InstallGuide',
 
@@ -298,10 +311,16 @@ sub configure
         'UploadToCPAN',
 
         # After Release
-        [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
+        ( $self->licence eq 'LICENSE' && -e 'LICENCE' ?
+            [ 'Run::AfterRelease' => 'remove old LICENCE' => { ':version' => '0.038', quiet => 1, eval => q!unlink 'LICENCE'! } ]
+            : ()),
+        ( $self->licence eq 'LICENCE' && -e 'LICENSE' ?
+            [ 'Run::AfterRelease' => 'remove old LICENSE' => { ':version' => '0.038', quiet => 1, eval => q!unlink 'LICENSE'! } ]
+            : ()),
         ( -e 'README.md' ?
             [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.038', quiet => 1, eval => q!unlink 'README.md'! } ]
             : ()),
+        [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
         [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } _uniq('README.md', 'README.pod', $self->copy_files_from_release) ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
@@ -424,7 +443,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 SYNOPSIS
 
@@ -475,6 +494,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     :version = 2.016
     exclude_filename = CONTRIBUTING
     exclude_filename = INSTALL
+    exclude_filename = LICENCE
     exclude_filename = LICENSE
     exclude_filename = META.json
     exclude_filename = Makefile.PL
@@ -487,9 +507,12 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     [MetaYAML]
     [MetaJSON]
-    [License]
     [Readme]
     [Manifest]
+    [License]
+    :version = 5.038
+    filename = LICENCE  ; for distributions where I have authority
+
     [GenerateFile::ShareDir / generate CONTRIBUTING]
     -dist = Dist-Zilla-PluginBundle-Author-ETHER
     -filename = CONTRIBUTING
@@ -649,7 +672,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Run::AfterBuild / .ackrc]
     :version = 0.38
     quiet = 1
-    run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi; if [[ %d =~ ^%n-[.[:xdigit:]]+$ ]]; then rm -f .latest; ln -s %d .latest; fi"
+    run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"
     [Run::AfterBuild / .latest]
     :version = 0.038
     quiet = 1
@@ -686,24 +709,36 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
 
     ;;; AfterRelease
-    [CopyFilesFromRelease]
-    filename = CONTRIBUTING
-    filename = Changes
-    filename = INSTALL
-    filename = LICENSE
-    filename = ppport.h
+    [Run::AfterRelease / remove old LICENCE]    ; if switching from LICENCE -> LICENSE
+    :version = 0.038
+    quiet = 1
+    eval = unlink 'LICENCE'
+
+    [Run::AfterRelease / remove old LICENSE]    ; if switching from LICENSE -> LICENCE
+    :version = 0.038
+    quiet = 1
+    eval = unlink 'LICENSE'
 
     [Run::AfterRelease / remove old READMEs]
     :version = 0.038
     quiet = 1
     eval = unlink 'README.md'
 
+    [CopyFilesFromRelease]
+    filename = CONTRIBUTING
+    filename = Changes
+    filename = INSTALL
+    filename = LICENCE
+    filename = LICENSE
+    filename = ppport.h
+
     [Git::Commit / release snapshot]
     :version = 2.020
     add_files_in = .
     allow_dirty = CONTRIBUTING
     allow_dirty = Changes
     allow_dirty = INSTALL
+    allow_dirty = LICENCE
     allow_dirty = LICENSE
     allow_dirty = README.md
     allow_dirty = README.pod
@@ -878,7 +913,7 @@ Available in this form since 0.076.
 A file, to be present in the build, which is copied back to the source
 repository at release time and committed to git. Can be repeated more than
 once. Defaults to:
-F<LICENSE>, F<CONTRIBUTING>, F<Changes>, F<ppport.h>, F<INSTALL>;
+F<LICENCE>, F<LICENSE>, F<CONTRIBUTING>, F<Changes>, F<ppport.h>, F<INSTALL>;
 defaults are appended to, rather than overwritten.
 
 =head2 surgical_podweaver
@@ -899,6 +934,15 @@ Available since 0.076.
 An integer that specifies how many columns (right-padded with whitespace) are
 allocated in Changes entries to the version string. Defaults to 10.
 
+=head2 licence (or license)
+
+Available since 0.101.
+
+A string that specifies the name to use for the licence file.  Defaults to
+C<LICENCE> for distributions where I (ETHER) have first-come, or C<LICENSE>
+otherwise. (The pod section for legal information is also adjusted
+appropriately.)
+
 =for stopwords customizations
 
 =head2 other customizations
