@@ -4,10 +4,11 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.100';
+our $VERSION = '0.101';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
+use Module::Runtime 'use_module';
 
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 
@@ -24,6 +25,7 @@ sub configure
         '@CorePrep',
         '-SingleEncoding',
         [ '-Transformer' => List => { transformer => 'List' } ],
+        [ '-Transformer' => Verbatim => { transformer => 'Verbatim' } ],
 
         [ 'Region' => 'header' ],
         'Name',
@@ -40,7 +42,7 @@ sub configure
         [ 'Region' => 'postlude' ],
         'Authors',
         [ 'Contributors' => { ':version' => '0.008' } ],
-        'Legal',
+        [ 'Legal' => { -f 'LICENCE' ? ( header => 'COPYRIGHT AND LICENCE' ) : () } ],
         [ 'Region' => 'footer' ],
     );
 }
@@ -101,6 +103,8 @@ sub _expand_config
         $payload = { region_name => $this_spec->[1], %$payload };
     }
 
+    use_module($class, $payload->{':version'}) if $payload->{':version'};
+
     # prepend '@Author::ETHER/' to each class name,
     # except for Generic and Collect which are left alone.
     $name = '@' . $self->_prefix . '/' . $name
@@ -123,7 +127,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 SYNOPSIS
 
@@ -155,6 +159,9 @@ following F<weaver.ini>, minus some optimizations:
     [-Transformer / List]
     transformer = List
 
+    [-Transformer / Verbatim]
+    transformer = Verbatim
+
     [Region / header]
     [Name]
     [Version]
@@ -186,6 +193,8 @@ following F<weaver.ini>, minus some optimizations:
     :version = 0.008
 
     [Legal]
+    header = COPYRIGHT AND LICENCE ; only if file is called LICENCE
+
     [Region / footer]
 
 This is also equivalent (other than section ordering) to:
